<?php
/**
 * Hotel Resort functions and definitions
 * @package Hotel Resort
 */

if ( ! function_exists( 'hotel_resort_setup' ) ) :

/* Theme Setup */

function hotel_resort_setup() {

	$GLOBALS['content_width'] = apply_filters( 'hotel_resort_content_width', 640 );

	load_theme_textdomain( 'hotel-resort', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'title-tag' );
	add_theme_support( 'custom-logo', array(
		'height'      => 240,
		'width'       => 240,
		'flex-height' => true,
	) );
	add_image_size('hotel-resort-homepage-thumb',240,145,true);
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'hotel-resort' ),
	) );
	add_theme_support( 'custom-background', array(
		'default-color' => 'f1f1f1'
	) );

	add_editor_style( array( 'css/editor-style.css', hotel_resort_font_url() ) );

}
endif; // hotel_resort_setup
add_action( 'after_setup_theme', 'hotel_resort_setup' );

/*Site URL*/
define('HOTEL_RESORT_CREDIT','https://www.logicalthemes.com/','hotel-resort');
if ( ! function_exists( 'hotel_resort_credit' ) ) {
	function hotel_resort_credit(){
			echo "<a href=".esc_url(HOTEL_RESORT_CREDIT)." target='_blank'>".esc_html('Logical Themes','hotel-resort')."</a>";
	}
}

/*radio button sanitization*/
function hotel_resort_sanitize_choices( $input, $setting ) {
    global $wp_customize;
    $control = $wp_customize->get_control( $setting->id );
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Theme Widgets Setup */
function hotel_resort_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'hotel-resort' ),
		'description'   => __( 'Appears on blog page sidebar', 'hotel-resort' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Posts and Pages Sidebar', 'hotel-resort' ),
		'description'   => __( 'Appears on posts and pages', 'hotel-resort' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar 3', 'hotel-resort' ),
		'description'   => __( 'Appears on posts and pages', 'hotel-resort' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 1', 'hotel-resort' ),
		'description'   => __( 'Appears in footer', 'hotel-resort' ),
		'id'            => 'footer-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 2', 'hotel-resort' ),
		'description'   => __( 'Appears in footer', 'hotel-resort' ),
		'id'            => 'footer-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 3', 'hotel-resort' ),
		'description'   => __( 'Appears in footer', 'hotel-resort' ),
		'id'            => 'footer-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Footer 4', 'hotel-resort' ),
		'description'   => __( 'Appears in footer', 'hotel-resort' ),
		'id'            => 'footer-4',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'hotel_resort_widgets_init' );

/* Theme Font URL */
function hotel_resort_font_url(){
	$font_url = '';	
	$ptsans = _x('on', 'PT Sans font:on or off','hotel-resort');	
	$roboto = _x('on', 'Roboto font:on or off','hotel-resort');	
	$OpenSans = _x('on', 'Open Sans font:on or off','hotel-resort');
	$Playball = _x('on', 'Playball font:on or off','hotel-resort');
	$Raleway = _x('on', 'Raleway font:on or off','hotel-resort');
	$Montserrat = _x('on', 'Montserrat:on or off','hotel-resort');
	$roboto_cond = _x('on', 'Roboto Condensed font:on or off','hotel-resort');
	
	if('off' !== $ptsans || 'off' !==  $roboto || 'off' !== $roboto_cond || 'off' !== $OpenSans || 'off' !== $Raleway){
		$font_family = array();
		
		if('off' !== $ptsans){
			$font_family[] = 'PT Sans:300,400,600,700,800,900';
		}		
		if('off' !== $roboto){
			$font_family[] = 'Roboto:400,700';
		}
		if('off' !== $OpenSans){
            $font_family[] = 'Open Sans:300,400,600,700,800,900';
        }
		if('off' !== $roboto_cond){
			$font_family[] = 'Roboto Condensed:400,700';
		}
		if('off' !== $Raleway){
            $font_family[] = 'Raleway:700';
        }
        if('off' !== $Playball){
			$font_family[] = 'Playball:300,400,600,700,800,900';
		}
		if('off' !== $Montserrat){
			$font_family[] = 'Montserrat:300,400,600,700,800,900';
		}		
		$query_args = array(
			'family'	=> urlencode(implode('|',$font_family)),
		);		
		$font_url = add_query_arg($query_args,'//fonts.googleapis.com/css');
	}
	return $font_url;
}

/* Theme enqueue scripts */
function hotel_resort_scripts() {
	wp_enqueue_style( 'hotel-resort-font', hotel_resort_font_url(), array() );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css');
	wp_enqueue_style( 'hotel-resort-style', get_stylesheet_uri() );
	wp_style_add_data( 'hotel-resort-style', 'rtl', 'replace' );
	wp_enqueue_style( 'hotel-resort-customcss', get_template_directory_uri() . '/css/custom.css' );
	wp_enqueue_style( 'font-awesome', get_template_directory_uri().'/css/font-awesome.css' );
	if ( is_home() || is_front_page() ) { 
		wp_enqueue_style( 'nivo-style', get_template_directory_uri().'/css/nivo-slider.css' );
		wp_enqueue_script( 'nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	}
	wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.js', array('jquery') ,'',true);
	wp_enqueue_script( 'hotel-resort-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'hotel_resort_scripts' );

function hotel_resort_ie_stylesheet(){
	wp_enqueue_style('hotel-resort-ie', get_template_directory_uri().'/css/ie.css', array('hotel-resort-ie-style'));
	wp_style_add_data( 'hotel-resort-ie', 'conditional', 'IE' );
}
add_action('wp_enqueue_scripts','hotel_resort_ie_stylesheet');


/* Custom template tags for this theme. */
require get_template_directory() . '/inc/template-tags.php';

/* Load Jetpack compatibility file. */
require get_template_directory() . '/inc/customizer.php';

/* Implement the Custom Header feature. */
require get_template_directory() . '/inc/custom-header.php';